@@ -372,24 +372,31 @@ class VacBot():
 
     def _handle_minor_map(self, event):
         response = event['body']['data']
-        
+
+        _LOGGER.debug("Handled minor_map : " + str(response['pieceIndex']))
+
         self.Map.AddMapPiece(response['pieceIndex'], response['pieceValue'])
 
     def _handle_major_map(self, event):
+        _LOGGER.debug("_handle_major_map begin")
         response = event['body']['data']
         
         values = response['value'].split(",")
 
         for i in range(64):
             if self.Map.isUpdatePiece(i, values[i]):
+                _LOGGER.debug("MapPiece" + str(i) + ' needs to be updated')
                 self.exc_command('getMinorMap', {'mid': response['mid'],'type': 'ol', 'pieceIndex': i})
 
     def _handle_cached_map(self, event):
         response = event['body']['data']
-        mapid = response['info'][0]['mid']
         
-        self.rooms = []
-        self.exc_command('getMapSet', {'mid': mapid,'type': 'ar'})
+        try:
+            mapid = response['info'][0]['mid']
+            self.rooms = []
+            self.exc_command('getMapSet', {'mid': mapid,'type': 'ar'})
+        except:
+            _LOGGER.warning("MapID not found -- did you finish your first auto cleaning?")
 
     def _handle_map_set(self, event):
         response = event['body']['data']
@@ -495,6 +502,7 @@ class VacBot():
 
     def refresh_liveMap(self):
         try:
+            _LOGGER.debug("Refresh_liveMap begin")
             self.exc_command('getMajorMap')
             self.live_map = self.Map.GetBase64Map()
         except XMPPError as err:
