@@ -97,53 +97,62 @@ class Map:
             #Flip
             im = ImageOps.flip(im)
             _LOGGER.debug("GetBase64Map finish flip")
-
-            #Crop
-            image_data = np.asarray(im)
-            _LOGGER.debug("image_data = np.asarray(im)")
-            del im
-            _LOGGER.debug("del im")
-
-            image_data_bw = image_data.max(axis=2)
-            _LOGGER.debug("image_data_bw = image_data.max(axis=2)")
-
-            non_empty_columns = np.where(image_data_bw.max(axis=0)>0)[0]
-            _LOGGER.debug("non_empty_columns = np.where(image_data_bw.max(axis=0)>0)[0]")
-
-            non_empty_rows = np.where(image_data_bw.max(axis=1)>0)[0]
-            _LOGGER.debug("non_empty_rows = np.where(image_data_bw.max(axis=1)>0)[0]")
-
-            cropBox = (min(non_empty_rows), max(non_empty_rows), min(non_empty_columns), max(non_empty_columns))
-            _LOGGER.debug("cropBox = (min(non_empty_rows), max(non_empty_rows), min(non_empty_columns), max(non_empty_columns))")
-
-            image_data_new = image_data[cropBox[0]:cropBox[1]+1, cropBox[2]:cropBox[3]+1 , :]
-            _LOGGER.debug("image_data_new = image_data[cropBox[0]:cropBox[1]+1, cropBox[2]:cropBox[3]+1 , :]")
-
-            del image_data
-            _LOGGER.debug("del image_data")
-
-            new_image = Image.fromarray(image_data_new)
-            _LOGGER.debug("new_image = Image.fromarray(image_data_new)")
-
-            del image_data_new
-            _LOGGER.debug("del image_data_new")
-
+            
             buffered = BytesIO()
             _LOGGER.debug("buffered = BytesIO()")
-
-            _LOGGER.debug("GetBase64Map finish crop")
-
-            new_image.save(buffered, format="PNG")
-            _LOGGER.debug("new_image.save(buffered, format=PNG)")
-
-            del new_image
-            _LOGGER.debug("del new_image")
-
-            _LOGGER.debug("GetBase64Map finish saving")
-
+            im.save(buffered, format="PNG")
+            _LOGGER.debug("im.save(buffered, format=PNG)")
             self.isMapUpdated = True
 
             base64Image = base64.b64encode(buffered.getvalue())
+            _LOGGER.debug("base64Image = base64.b64encode(buffered.getvalue())")
+            
+            #Crop
+            #image_data = np.asarray(im)
+            #_LOGGER.debug("image_data = np.asarray(im)")
+            #del im
+            #_LOGGER.debug("del im")
 
-            _LOGGER.debug("GetBase64Map done")
+            #image_data_bw = image_data.max(axis=2)
+            #_LOGGER.debug("image_data_bw = image_data.max(axis=2)")
+
+            #non_empty_columns = np.where(image_data_bw.max(axis=0)>0)[0]
+            #_LOGGER.debug("non_empty_columns = np.where(image_data_bw.max(axis=0)>0)[0]")
+
+            #non_empty_rows = np.where(image_data_bw.max(axis=1)>0)[0]
+            #_LOGGER.debug("non_empty_rows = np.where(image_data_bw.max(axis=1)>0)[0]")
+
+            #cropBox = (min(non_empty_rows), max(non_empty_rows), min(non_empty_columns), max(non_empty_columns))
+            #_LOGGER.debug("cropBox = (min(non_empty_rows), max(non_empty_rows), min(non_empty_columns), max(non_empty_columns))")
+
+            #image_data_new = image_data[cropBox[0]:cropBox[1]+1, cropBox[2]:cropBox[3]+1 , :]
+            #_LOGGER.debug("image_data_new = image_data[cropBox[0]:cropBox[1]+1, cropBox[2]:cropBox[3]+1 , :]")
+
+            #del image_data
+            #_LOGGER.debug("del image_data")
+
+            #new_image = Image.fromarray(image_data_new)
+            #_LOGGER.debug("new_image = Image.fromarray(image_data_new)")
+
+            #del image_data_new
+            #_LOGGER.debug("del image_data_new")
+
+            #buffered = BytesIO()
+            #_LOGGER.debug("buffered = BytesIO()")
+
+            #_LOGGER.debug("GetBase64Map finish crop")
+
+            #new_image.save(buffered, format="PNG")
+            #_LOGGER.debug("new_image.save(buffered, format=PNG)")
+
+            #del new_image
+            #_LOGGER.debug("del new_image")
+
+            #_LOGGER.debug("GetBase64Map finish saving")
+
+            #self.isMapUpdated = True
+
+            #base64Image = base64.b64encode(buffered.getvalue())
+
+            #_LOGGER.debug("GetBase64Map done")
         return base64Image
\ No newline at end of file
